Installation
============

.. note::

    When installing ``earthkit`` all the available components will be installed for you. If you only need certain components you can install them one by one.

Installing earthkit
----------------------------

Install **earthkit** with python3 (>= 3.8) and ``pip`` as follows:

.. code-block:: bash

    python3 -m pip install earthkit

.. Alternatively, install via ``conda`` with:

.. .. code-block:: bash

..     conda install earthkit -c conda-forge

.. This will bring in some necessary binary dependencies for you.

Installing the binary dependencies
--------------------------------------

This is the list of components with have binary dependencies. Please click on the links to see the installation instructions.

-  `eartkit-data <https://earthkit-data.readthedocs.io/en/latest/install.html#installing-the-binary-dependencies>`_
